package com.userauth.restuserauth.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.userauth.restuserauth.dto.AuthRequest;
import com.userauth.restuserauth.dto.AuthResponse;
import com.userauth.restuserauth.model.Role;
import com.userauth.restuserauth.model.User;
import com.userauth.restuserauth.repository.UserRepository;
import com.userauth.restuserauth.security.JwtTokenProvider;

@RestController
@RequestMapping("/api/auth")
public class AuthController {

    // 添加 SLF4J Logger
    private static final Logger logger = LoggerFactory.getLogger(AuthController.class);

    @Autowired
    private AuthenticationManager authenticationManager;

    @Autowired
    private UserRepository userRepository;

    @Autowired
    private PasswordEncoder passwordEncoder;

    @Autowired
    private JwtTokenProvider tokenProvider;

    @PostMapping("/login")
    public ResponseEntity<?> authenticateUser(@RequestBody AuthRequest loginRequest) {
        try {
            Authentication authentication = authenticationManager.authenticate(
                new UsernamePasswordAuthenticationToken(
                    loginRequest.getUsername(),
                    loginRequest.getPassword()
                )
            );

            String jwt = tokenProvider.generateToken(authentication);
            return ResponseEntity.ok(new AuthResponse(jwt, "登录成功"));
        } catch (Exception e) {
             // 关键改动：记录详细的错误日志，但仍然对客户端返回通用错误信息
             logger.error("用户 '{}' 认证失败：{}", loginRequest.getUsername(), e.getMessage());
             return new ResponseEntity<>("用户名或密码错误", HttpStatus.UNAUTHORIZED);
        }
    }

    @PostMapping("/register")
    public ResponseEntity<?> registerUser(@RequestBody AuthRequest registerRequest) {
        if (userRepository.findByUsername(registerRequest.getUsername()).isPresent()) {
            return new ResponseEntity<>("用户名已存在", HttpStatus.BAD_REQUEST);
        }

        // 建议：检查电子邮件是否也已存在
        // if (userRepository.findByEmail(registerRequest.getEmail()).isPresent()) {
        //     return new ResponseEntity<>("该邮箱已被注册", HttpStatus.BAD_REQUEST);
        // }

        User user = new User();
        user.setUsername(registerRequest.getUsername());
        user.setPassword(passwordEncoder.encode(registerRequest.getPassword()));
        user.setEmail(registerRequest.getEmail());
        user.setPhone(registerRequest.getPhone());
        user.setRole(Role.USER); // 为新用户设置默认角色

        userRepository.save(user);

        return new ResponseEntity<>("用户注册成功", HttpStatus.CREATED);
    }
}
